@@ -14,9 +14,9 @@ use File::Fetch;
 use IO::File;
 use File::Spec::Functions;
 use File::Path;
-use Regexp::Assemble;
-use Sort::Versions;
-use Config::IniFiles;
+use CPANPLUS::YACSmoke::ReAssemble;
+use CPANPLUS::YACSmoke::SortVers;
+use CPANPLUS::YACSmoke::IniFiles;
 
 use vars qw($VERSION);
 
@@ -28,14 +28,14 @@ require Exporter;
 
 our @ISA = qw( Exporter );
 our %EXPORT_TAGS = (
-  'all'      => [ qw( mark test excluded purge flush ) ],
+  'all'      => [ qw( mark test excluded purge flush reindex) ],
   'default'  => [ qw( mark test excluded ) ],
 );
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT    = ( @{ $EXPORT_TAGS{'default'} } );
 
-$VERSION = '0.56';
+$VERSION = '0.60';
 
 {
   my %Checked;
@@ -95,10 +95,10 @@ sub new {
   my $exclude_dists;
   my $config_file = catfile( $conf->get_conf('base'), CONFIG_FILE );
   if ( -r $config_file ) {
-     my $cfg = Config::IniFiles->new(-file => $config_file);
+     my $cfg = CPANPLUS::YACSmoke::IniFiles->new(-file => $config_file);
      my @list = $cfg->val( 'CONFIG', 'exclude_dists' );
      if ( @list ) {
-        $exclude_dists = Regexp::Assemble->new();
+        $exclude_dists = CPANPLUS::YACSmoke::ReAssemble->new();
         $exclude_dists->add( @list );
      }
   }
@@ -330,6 +330,21 @@ sub flush {
   return 1;
 }
 
+sub reindex {
+  my $self;
+  eval {
+    if ( (ref $_[0]) && $_[0]->isa(__PACKAGE__) ) {
+	$self = shift;
+    }
+  };
+  $self ||= __PACKAGE__->new();
+  $self->{conf}->set_conf( no_update => 0 );
+  $self->{cpanplus}->reload_indices( update_source => 1 );
+  $self->{conf}->set_conf( no_update => 1 )
+    if glob( catfile( $self->{conf}->get_conf('base'), $self->{conf}->_get_source('stored') .'*'. STORABLE_EXT, ) );
+  return 1;
+}
+
 sub _is_excluded_dist {
   my $self = shift;
   my $dist = shift || return;
@@ -520,6 +535,10 @@ the intention is for this distribution to be used on any OS that CPANPLUS
 is installed on. In this case not all OSs support the full range of return
 values from the stat function.
 
+=item reindex
+
+Make L<CPANPLUS> reload its indices.
+
 =back
 
 =head1 OBJECT INTERFACE
